# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector.api.chats_api import ChatsApi  # noqa: E501


class TestChatsApi(unittest.IsolatedAsyncioTestCase):
    """ChatsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_chat_ai_usage_insert(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert

        Chat Ai Usage Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_delete(self) -> None:
        """Test case for chat_api_chat_delete

        Chat Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_get(self) -> None:
        """Test case for chat_api_chat_get

        Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_join(self) -> None:
        """Test case for chat_api_chat_join

        Chat Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_leave(self) -> None:
        """Test case for chat_api_chat_leave

        Chat Leave  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mark_as_read(self) -> None:
        """Test case for chat_api_chat_mark_as_read

        Chat Mark As Read  # noqa: E501
        """
        pass

    async def test_chat_api_chat_member_ban(self) -> None:
        """Test case for chat_api_chat_member_ban

        Chat Member Ban  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_list(self) -> None:
        """Test case for chat_api_chat_members_list

        Chat Members List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_update(self) -> None:
        """Test case for chat_api_chat_members_update

        Chat Members Update  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_delete(self) -> None:
        """Test case for chat_api_chat_message_delete

        Chat Message Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_get(self) -> None:
        """Test case for chat_api_chat_message_get

        Chat Message Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_add(self) -> None:
        """Test case for chat_api_chat_messages_add

        Chat Messages Add  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_insert(self) -> None:
        """Test case for chat_api_chat_messages_insert

        Chat Messages Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_list(self) -> None:
        """Test case for chat_api_chat_messages_list

        Chat Messages List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mute(self) -> None:
        """Test case for chat_api_chat_mute

        Chat Mute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_patch(self) -> None:
        """Test case for chat_api_chat_patch

        Chat Patch  # noqa: E501
        """
        pass

    async def test_chat_api_chat_private_join(self) -> None:
        """Test case for chat_api_chat_private_join

        Chat Private Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_start(self) -> None:
        """Test case for chat_api_chat_session_start

        Chat Session Start  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_stop(self) -> None:
        """Test case for chat_api_chat_session_stop

        Chat Session Stop  # noqa: E501
        """
        pass

    async def test_chat_api_chat_unmute(self) -> None:
        """Test case for chat_api_chat_unmute

        Chat Unmute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_update(self) -> None:
        """Test case for chat_api_chat_update

        Chat Update  # noqa: E501
        """
        pass

    async def test_chat_api_chats_add(self) -> None:
        """Test case for chat_api_chats_add

        Chats Add  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list(self) -> None:
        """Test case for chat_api_chats_list

        Chats List  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list_available(self) -> None:
        """Test case for chat_api_chats_list_available

        Chats List Available  # noqa: E501
        """
        pass

    async def test_chat_api_get_total_unread_messages(self) -> None:
        """Test case for chat_api_get_total_unread_messages

        Get Total Unread Messages  # noqa: E501
        """
        pass

    async def test_chat_api_stop_agent_run(self) -> None:
        """Test case for chat_api_stop_agent_run

        Stop Agent Run  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
